metaknowledge
=============

*metaknowledge* is a Python3 library that simplifies bibliometric
research using data from various sources. It reads a directory of plain
text files containing meta-data on publications and citations, and
writes to a variety of data structures that are suitable for
quantitative, network, and text analyses. It handles large datasets
(e.g. several million records) efficiently.

The website can be found at
`networkslab.org/metaknowledge <http://networkslab.org/metaknowledge/>`__.

Major Update
============

The version of *metaknowledge* currently available is the second major
release and is not backwards compatible with the previous versions. If
you wish to use an older version they are still available on github or
pip.

Installing
----------

To install run ``python3 setup.py install``

For information on alternate installs read the documentation at the
`website <http://networkslab.org/metaknowledge/installation/>`__.
